@@ -24,16 +24,18 @@ def test_delegation_to_send_rpc():
 
     with mock.patch('nameko.sending.send_rpc') as send_rpc:
         nova.call(connection=conn, context=ctx, topic=topic,
-                    msg=msg, timeout=timeout, options=options)
+            msg=msg, timeout=timeout, options=options)
 
         send_rpc.assert_called_with(conn, context=ctx, exchange=exchange,
-                            topic=topic, method=method, args=args, timeout=timeout)
+                            topic=topic, method=method, args=args,
+                            timeout=timeout)
 
         nova.cast(connection=conn, context=ctx, topic=topic,
-                    msg=msg, options=options)
+            msg=msg, options=options)
 
         send_rpc.assert_called_with(conn, context=ctx, exchange=exchange,
-                            topic=topic, method=method, args=args, noreply=True)
+                            topic=topic, method=method, args=args,
+                            noreply=True)
 
         nova.fanout_cast(connection=conn, context=ctx, topic=topic, msg=msg)
 
